const svg = d3.select('svg');

const width = +svg.attr('width'),
      height = +svg.attr('height');

const render = data => {
  
  const xValue = d => d.population,
        yValue = d => d.name,
        margin = {top: 60, right: 40, bottom: 60, left: 120},
        innerWidth = width - margin.left - margin.right,
        innerHeight = height - margin.top - margin.bottom;
  
  const xScale = d3.scaleLinear()
  	.domain([0, d3.max(data, xValue)])
  	.range([0, innerWidth]);
  
  const yScale = d3.scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.3);
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  g.append('g')
  	.attr('class', 'y-axis')
  	.call(d3.axisLeft(yScale))
  	.selectAll('.domain, .tick line')
  		.remove();
  
  
  
  const xAxisTickFormat = number => 
  	d3.format('.2s')(number)
  	.replace('G', 'B')
  	.replace('.', ',');
  
  const xAxis = d3.axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight);
  
  const xAxisG = g.append('g')
  	.attr('class', 'x-axis')
  	.attr('transform', `translate(0, ${innerHeight})`)
  	.call(xAxis)
  	
	xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.text('Population')
  	.attr('fill', '#999')
  	.attr('x', innerWidth/2)
  	.attr('y', 40)
  
  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr('y', d => yScale(yValue(d)))
  		.attr('width', d => xScale(xValue(d)))
  		.attr('height', yScale.bandwidth())
  
  g.append('text')
  	.attr('class', 'h1')
  	.attr('y', -10)
  	.text('Top 10 most populous countires')
  	.style('font-weight', 'bold')
  
};

d3.csv('data.csv').then(data => {
	data.forEach(d => {
  	d.population = +d.population
	});
	render(data);
});

